#!/bin/bash -e

function Usage {
    echo "USAGE: Formats /mnt to ext4 IF it is ntfs"
    echo "$0 [-y]"
    echo -e "\t-y Automatically proceed without confirmation prompt"
    exit 1
}

function PromptForConfirmation {
    echo "/mnt is formatted ntfs. Do you want to format ext4?"
    select yn in "Yes" "No"; do
        case $yn in
            Yes ) return;;
            No ) echo "Operation cancelled"; exit;;
        esac
    done
}

while getopts ":y" opt; do
  case $opt in
    y)
      skipConfirm=yes
      ;;
    \?)
      Usage
      ;;
    :)
      echo "Option -$OPTARG requires an argument." >&2
      Usage
      ;;
  esac
done

# Sometimes /mnt points to the drive, not the partition
ephemeralPartition=$(grep /mnt /etc/fstab | awk '{print $1}')
if [[ "${ephemeralPartition}" == *"_resource" ]]; then
    ephemeralPartition="${ephemeralPartition}-part1"
fi

if [ ! -b "$ephemeralPartition" ]; then
    echo "ERROR: Partition $ephemeralPartition does not exist"
    exit 1
fi

echo "Checking filesystem on $ephemeralPartition"
fs=$(blkid -c /dev/null $ephemeralPartition | awk '{print $3}')
if [ "$fs" == "TYPE=\"ntfs\"" ]; then
    if [ "$skipConfirm" != "yes" ]; then
       PromptForConfirmation
    fi
    echo "/mnt is NTFS - will format as ext4"
    ! umount /mnt
    echo y | mkfs.ext4 -q $ephemeralPartition
    mount /mnt
    fs=$(blkid -c /dev/null $ephemeralPartition | awk '{print $3}')
fi

if [ "$fs" != "TYPE=\"ext4\"" ]; then
    echo "ERROR: filesystem should be ext4, instead it's [$fs]"
    exit 1
else
    echo "OK: /mnt is ext4"
fi
